FullyQualifiedClassName

Struct FullyQualifiedClassName 

pub struct FullyQualifiedClassName { /* private fields */ }
What does this represent?

A fully qualified class name represented by a package and a local identifier.

Implementations

Source

impl FullyQualifiedClassName

pub fn new(package_name: SharedString, name: SharedString) -> Self

Creates a new fully qualified class name from a package and local name.

pub fn from_ident(name: SharedString) -> Self

Creates a fully qualified class name in the default package.

pub fn package_name(&self) -> &SharedString

Returns the package portion (empty for the default package).

pub fn name(&self) -> &SharedString

Returns the local identifier portion.

pub fn is_default_package(&self) -> bool

Returns true if this name is in the default package.