pub struct FullyQualifiedClassName { /* private fields */ }Expand description
What does this represent?
A fully qualified class name represented by a package and a local identifier.
Implementations
Sourceimpl FullyQualifiedClassName
impl FullyQualifiedClassName
Sourcepub fn new(package_name: SharedString, name: SharedString) -> Self
pub fn new(package_name: SharedString, name: SharedString) -> Self
Creates a new fully qualified class name from a package and local name.
Sourcepub fn from_ident(name: SharedString) -> Self
pub fn from_ident(name: SharedString) -> Self
Creates a fully qualified class name in the default package.
Sourcepub fn package_name(&self) -> &SharedString
pub fn package_name(&self) -> &SharedString
Returns the package portion (empty for the default package).
Sourcepub fn name(&self) -> &SharedString
pub fn name(&self) -> &SharedString
Returns the local identifier portion.
Sourcepub fn is_default_package(&self) -> bool
pub fn is_default_package(&self) -> bool
Returns true if this name is in the default package.